@@ -3,8 +3,8 @@
 #include <cassert>
 #include <cstdio>
 #include <netdb.h>
-#include <rak/address_info.h>
-#include <rak/error_number.h>
+#include <torrent/net/network_config.h>
+#include <torrent/net/network_manager.h>
 #include <torrent/net/resolver.h>
 #include <torrent/tracker/dht_controller.h>
 #include <torrent/tracker/tracker.h>
@@ -28,7 +28,7 @@ tracker_set_enabled(torrent::tracker::Tracker* tracker, bool state) {
 
 torrent::Object
 apply_dht_add_node(const std::string& arg) {
-  if (!torrent::dht_controller()->is_valid())
+  if (!torrent::runtime::network_manager()->is_dht_valid())
     throw torrent::input_error("DHT not enabled.");
 
   int port;
@@ -59,7 +59,7 @@ apply_dht_add_node(const std::string& arg) {
       }
 
       lt_log_print(torrent::LOG_DHT_CONTROLLER, "dht.add_node : %s", host_str.c_str());
-      torrent::dht_controller()->add_node(sa.get(), port);
+      torrent::runtime::network_manager()->dht_add_peer_node(sa.get(), port);
   });
 
   return torrent::Object();
@@ -142,11 +142,16 @@ initialize_command_tracker() {
   CMD2_VAR_VALUE      ("trackers.numwant",    -1);
   CMD2_VAR_BOOL       ("trackers.use_udp",    true);
 
+  auto dht_manager = control->dht_manager();
+
   CMD2_ANY_STRING_V   ("dht.mode.set",          std::bind(&core::DhtManager::set_mode, control->dht_manager(), std::placeholders::_2));
-  // TODO: This should query DhtController.
-  CMD2_VAR_VALUE      ("dht.port",              int64_t(6881));
+  CMD2_ANY            ("dht.port",              [](auto, auto) { return torrent::runtime::network_manager()->dht_controller()->port(); });
+  CMD2_ANY_VALUE_V    ("dht.port.set",          [](auto, auto) {
+      lt_log_print(torrent::LOG_DHT_ERROR, "dht.port.set is no longer supported, use dht.override_port.set", 0);
+    });
+  CMD2_ANY            ("dht.override_port",     std::bind(&torrent::net::NetworkConfig::override_dht_port, torrent::config::network_config()));
+  CMD2_ANY_VALUE_V    ("dht.override_port.set", std::bind(&torrent::net::NetworkConfig::set_override_dht_port, torrent::config::network_config(), std::placeholders::_2));
+
   CMD2_ANY_STRING     ("dht.add_node",          std::bind(&apply_dht_add_node, std::placeholders::_2));
-  CMD2_ANY            ("dht.statistics",        std::bind(&core::DhtManager::dht_statistics, control->dht_manager()));
-  CMD2_ANY            ("dht.throttle.name",     std::bind(&core::DhtManager::throttle_name, control->dht_manager()));
-  CMD2_ANY_STRING_V   ("dht.throttle.name.set", std::bind(&core::DhtManager::set_throttle_name, control->dht_manager(), std::placeholders::_2));
+  CMD2_ANY            ("dht.statistics",        std::bind(&core::DhtManager::dht_statistics, dht_manager));
 }
