@@ -1,11 +1,12 @@
 #include "config.h"
 
+#include "download_factory.h"
+
 #include <cstdlib>
 #include <fstream>
 #include <functional>
 #include <sstream>
 #include <stdexcept>
-
 #include <rak/path.h>
 #include <torrent/utils/log.h>
 #include <torrent/utils/resume.h>
@@ -14,18 +15,15 @@
 #include <torrent/exceptions.h>
 #include <torrent/rate.h>
 #include <torrent/data/file_utils.h>
+#include <torrent/net/http_stack.h>
 
-#include "rpc/parse_commands.h"
-
-#include "curl_get.h"
 #include "control.h"
-#include "http_queue.h"
 #include "globals.h"
-#include "manager.h"
-
-#include "download.h"
-#include "download_factory.h"
-#include "download_store.h"
+#include "core/download.h"
+#include "core/download_store.h"
+#include "core/http_queue.h"
+#include "core/manager.h"
+#include "rpc/parse_commands.h"
 
 namespace core {
 
@@ -77,9 +75,7 @@ DownloadFactory::~DownloadFactory() {
   torrent::this_thread::scheduler()->erase(&m_task_load);
   torrent::this_thread::scheduler()->erase(&m_task_commit);
 
-  delete m_stream;
   delete m_object;
-  m_stream = NULL;
 }
 
 void
@@ -94,7 +90,7 @@ DownloadFactory::load_raw_data(const std::string& input) {
   if (m_stream)
     throw torrent::internal_error("DownloadFactory::load*() called on an object with m_stream != NULL");
 
-  m_stream = new std::stringstream(input);
+  m_stream.reset(new std::stringstream(input));
   m_loaded = true;
 }
 
@@ -110,17 +106,18 @@ DownloadFactory::receive_load() {
 
   if (is_network_uri(m_uri)) {
     // Http handling here.
-    m_stream = new std::stringstream;
+    m_stream.reset(new std::stringstream);
+
     HttpQueue::iterator itr = m_manager->http_queue()->insert(m_uri, m_stream);
 
-    (*itr)->signal_done().push_front(std::bind(&DownloadFactory::receive_loaded, this));
-    (*itr)->signal_failed().push_front(std::bind(&DownloadFactory::receive_failed, this, std::placeholders::_1));
+    itr->add_done_slot([this]() { receive_loaded(); });
+    itr->add_failed_slot([this](const std::string& error) { receive_failed(error); });
 
     m_variables["tied_to_file"] = (int64_t)false;
 
   } else if (is_magnet_uri(m_uri)) {
     // DEBUG: Use m_object.
-    m_stream = new std::stringstream();
+    m_stream.reset(new std::stringstream());
     *m_stream << "d10:magnet-uri" << m_uri.length() << ":" << m_uri << "e";
 
     m_variables["tied_to_file"] = (int64_t)false;
@@ -172,8 +169,8 @@ DownloadFactory::receive_success() {
   else
     tracker_key = random() % (std::numeric_limits<uint32_t>::max() - 1) + 1;
 
-  Download* download = m_stream != NULL ?
-    m_manager->download_list()->create(m_stream, tracker_key, m_printLog) :
+  Download* download = m_stream != nullptr ?
+    m_manager->download_list()->create(m_stream.get(), tracker_key, m_printLog) :
     m_manager->download_list()->create(m_object, tracker_key, m_printLog);
 
   m_object = NULL;
@@ -194,8 +191,8 @@ DownloadFactory::receive_success() {
 
     torrent::Object::list_type& commands = meta.insert_key("commands", torrent::Object::create_list()).as_list();
 
-    for (command_list_type::iterator itr = m_commands.begin(); itr != m_commands.end(); ++itr)
-      commands.push_back(*itr);
+    for (auto& m_command : m_commands)
+      commands.push_back(m_command);
   }
 
   if (m_session) {
@@ -289,9 +286,8 @@ DownloadFactory::receive_success() {
     if (torrent::log_groups[torrent::LOG_TORRENT_DEBUG].valid())
       log_created(download, rtorrent);
 
-    std::for_each(m_commands.begin(), m_commands.end(), [&download](const std::string& cmd) {
-        rpc::parse_command_multiple_std(cmd, rpc::make_target(download));
-      });
+    for (const auto& command : m_commands)
+      rpc::parse_command_multiple_std(command, rpc::make_target(download));
 
     if (m_manager->download_list()->find(infohash) == m_manager->download_list()->end())
       throw torrent::input_error("The newly created download was removed.");
@@ -336,8 +332,8 @@ DownloadFactory::log_created(Download* download, torrent::Object* rtorrent) {
 
   dump << "---COMMANDS---" << std::endl;
 
-  for (command_list_type::const_iterator itr = m_commands.begin(); itr != m_commands.end(); itr++) {
-    dump << *itr << std::endl;
+  for (const auto& m_command : m_commands) {
+    dump << m_command << std::endl;
   }
 
   std::string dump_str = dump.str();
