@@ -1,39 +1,3 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 // Provides a filtered and sorted list of downloads that can be
 // updated auto-magically.
 //
@@ -50,11 +14,11 @@
 #define RTORRENT_CORE_VIEW_DOWNLOADS_H
 
 #include <functional>
+#include <list>
 #include <string>
 #include <vector>
-
-#include <rak/timer.h>
 #include <torrent/object.h>
+#include <torrent/utils/scheduler.h>
 
 #include "globals.h"
 
@@ -75,7 +39,7 @@ public:
 
   using base_type::size_type;
 
-  View() {}
+  View() = default;
   ~View();
 
   void               initialize(const std::string& name);
@@ -114,8 +78,11 @@ public:
   void set_visible(Download* download);
   void set_not_visible(Download* download);
 
-  void next_focus();
-  void prev_focus();
+  void next_focus(unsigned int i);
+  void prev_focus(unsigned int i);
+
+  void next_focus() { next_focus(1); }
+  void prev_focus() { prev_focus(1); }
 
   void sort();
 
@@ -146,8 +113,8 @@ public:
   //
   // Currently initialized to rak::timer(), though perhaps we should
   // use cachedTimer.
-  rak::timer last_changed() const { return m_lastChanged; }
-  void       set_last_changed(const rak::timer& t = ::cachedTime) { m_lastChanged = t; }
+  auto                last_changed() const { return m_last_changed; }
+  void                set_last_changed(std::chrono::microseconds t = torrent::this_thread::cached_time()) { m_last_changed = t; }
 
   // Don't connect any slots until after initialize else it get's
   // triggered when adding the Download's in DownloadList.
@@ -184,10 +151,10 @@ private:
   torrent::Object    m_event_added;
   torrent::Object    m_event_removed;
 
-  rak::timer         m_lastChanged;
+  std::chrono::microseconds m_last_changed{};
 
-  signal_void        m_signal_changed;
-  rak::priority_item m_delayChanged;
+  signal_void                    m_signal_changed;
+  torrent::utils::SchedulerEntry m_delay_changed;
 };
 
 } // namespace core
