@@ -23,6 +23,22 @@ namespace input {
 
 namespace ui {
 
+enum NavigationKeymap {
+  RT_KEY_LEFT,
+  RT_KEY_RIGHT,
+  RT_KEY_UP,
+  RT_KEY_DOWN,
+  RT_KEY_PPAGE,
+  RT_KEY_NPAGE,
+  RT_KEY_HOME,
+  RT_KEY_END,
+  RT_KEY_DELETE_ITEM,
+  RT_KEY_DISCONNECT_PEER,
+  RT_KEY_DISPLAY_LOG,
+  RT_KEY_TOGGLE_LAYOUT,
+  RT_KEYMAP_MAX
+};
+
 class DownloadList;
 
 typedef std::vector<std::string> ThrottleNameList;
@@ -43,11 +59,11 @@ public:
   void                init(Control* c);
   void                cleanup();
 
-  WTitle*             window_title()                          { return m_windowTitle.get(); }
-  WStatusbar*         window_statusbar()                      { return m_windowStatusbar.get(); }
-  WInput*             window_input()                          { return m_windowInput.get(); }
+  const auto&         window_title() const                    { return m_windowTitle; }
+  const auto&         window_statusbar() const                { return m_windowStatusbar; }
+  const auto&         window_input() const                    { return m_windowInput; }
 
-  DownloadList*       download_list()                         { return m_downloadList.get(); }
+  const auto&         download_list() const                   { return m_downloadList; }
 
   void                set_down_throttle(unsigned int throttle);
   void                set_up_throttle(unsigned int throttle);
@@ -80,6 +96,10 @@ public:
   void                save_input_history();
   void                clear_input_history();
 
+  const std::string&  keymap_style()                          { return m_keymap_style; }
+  void                set_keymap_style(const std::string& style);
+  const int           navigation_key(NavigationKeymap key);
+
 private:
   void                setup_keys();
 
@@ -104,6 +124,9 @@ private:
 
   void                reset_input_history_attributes(ui::DownloadList::Input type);
 
+  std::string         m_keymap_style;
+  const int*          m_keymap;
+
   ThrottleNameList    m_throttle_up_names;
   ThrottleNameList    m_throttle_down_names;
 };
